# tsforest

[![Build Status][travis-image]][travis-url]  [![PyPI version][pypi-image]][pypi-url]  [![PyPI download][download-image]][pypi-url]


Time series forecasting based on tree ensembles learning


[travis-image]: https://travis-ci.org/mavillan/tsforest.svg?branch=master
[travis-url]: https://travis-ci.org/mavillan/tsforest
[pypi-image]: http://img.shields.io/pypi/v/tsforest.svg
[download-image]: http://img.shields.io/pypi/dm/tsforest.svg
[pypi-url]: https://pypi.org/project/tsforest/
